@@ -46,13 +46,6 @@ def list_email_verified():
     return response['Identities']
 
 
-def zipdir(path, ziph):
-    # ziph is zipfile handle
-    for root, dirs, files in os.walk(path):
-        for file in files:
-            ziph.write(os.path.join(root, file))
-
-
 def send_notifications(email, sender, email_configuration):
     """This function sends email of a log file """
 
@@ -71,10 +64,8 @@ def send_notifications(email, sender, email_configuration):
     # The full path to the file that will be attached to the email.
     # LOG_PATH = email_configuration.get('Log_path')
     ATTACHMENT = getattr(settings, "LOG_PATH", None)
-
-    zipf = zipfile.ZipFile('media/Zipped_file.zip', 'w', zipfile.ZIP_DEFLATED)
-    zipdir(ATTACHMENT, zipf)
-    zipf.close()
+    zipfile.ZipFile('media/Zipped_file.zip', mode='w').write(ATTACHMENT)
+    print("File Created successfully..")
 
     # The HTML body of the email.
     file_name = email_configuration.get('HTML_File')
@@ -86,12 +77,12 @@ def send_notifications(email, sender, email_configuration):
         unsubscribe=email_configuration.get('Unsubscribe_Email_ID'))
     # Define the attachment part and encode it using MIMEApplication.
     att = MIMEApplication(open('media/Zipped_file.zip', 'rb').read())
-    # os.remove('Zipped_file.zip')
+    os.remove('Zipped_file.zip')
 
     # Add a header to tell the email client to treat this part as an
     # attachment, and to give the attachment a name.
     att.add_header('Content-Disposition', 'attachment',
-                   filename="OpenLXP notifications"+".zip")
+                   filename="OpenLXP notifications" + ".zip")
 
     for each_recipient in RECIPIENT:
         try:
